Chargers are specified as one charger per line with the following fields:

- `charger_id`: the unique identifier of the charger type
- `energy_type`: the type of energy (electric | gasoline)
- `rate`: the rate of discharge
- `units`: the units for the rate of discharge
